@@ -16,7 +16,7 @@
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/gperl.h,v 1.46 2006/11/23 18:42:33 kaffeetisch Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/gperl.h,v 1.47 2007/06/23 17:07:01 kaffeetisch Exp $
  */
 
 #ifndef _GPERL_H_
@@ -360,6 +360,14 @@ GBookmarkFile * SvGBookmarkFile (SV * sv);
 
 const char * gperl_param_spec_package_from_type (GType gtype);
 
+/*
+ * gutils.h / GUtils.xs
+ */
+#if GLIB_CHECK_VERSION (2, 13, 0) /* FIXME: 2.14 */
+GUserDirectory SvGUserDirectory (SV *sv);
+SV * newSVGUserDirectory (GUserDirectory dir);
+#endif
+
 /*
  * helpful debugging stuff
  */
